@@ -43,6 +43,7 @@
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
 #define HAVE_INTTYPES_H 1
+#define HAVE_IMMINTRIN_H 1
 /* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
 #define HAVE_LINK_H 1
@@ -109,7 +110,7 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 #define HAVE_SYSTEMD 1
-/* #undef HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES */
+#define HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES 1
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -127,7 +128,6 @@
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-#define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
 #define HAVE_INDEX 1
@@ -198,7 +198,7 @@
 #define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
-#define HAVE_PTHREAD_KEY_DELETE 1
+/* #undef HAVE_PTHREAD_KEY_DELETE */
 /* #undef HAVE_PTHREAD_KILL */
 #define HAVE_PTHREAD_RWLOCK_RDLOCK 1
 #define HAVE_PTHREAD_SIGMASK 1
@@ -206,7 +206,7 @@
 #define HAVE_PTHREAD_YIELD_ZERO_ARG 1
 #define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
 #define HAVE_PUTENV 1
-#define HAVE_READDIR_R 1
+/* #undef HAVE_READDIR_R */
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -255,9 +255,10 @@
 /* #undef HAVE_SOCKADDR_IN6_SIN6_LEN */
 #define STRUCT_TIMESPEC_HAS_TV_SEC 1
 #define STRUCT_TIMESPEC_HAS_TV_NSEC 1
+#define STRUCT_TM_HAS_TM_GMTOFF 1
 
 /* this means that valgrind headers and macros are available */
-/* #undef HAVE_VALGRIND_MEMCHECK_H */
+#define HAVE_VALGRIND_MEMCHECK_H 1
 
 /* this means WITH_VALGRIND - we change some code paths for valgrind */
 /* #undef HAVE_valgrind */
@@ -377,14 +378,13 @@
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
 #define HAVE_ERR_remove_thread_state 1
-#define HAVE_X509_check_host 1
+/* #undef HAVE_X509_check_host */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef NO_FCNTL_NONBLOCK */
-#define NO_ALARM 1
 
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
@@ -437,8 +437,8 @@
 /* #undef USE_SYMDIR */
 
 /* Character sets and collations */
-#define MYSQL_DEFAULT_CHARSET_NAME "latin1"
-#define MYSQL_DEFAULT_COLLATION_NAME "latin1_swedish_ci"
+#define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
+#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_uca1400_ai_ci"
 
 #define USE_MB
 #define USE_MB_IDENT
@@ -491,17 +491,10 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-/* #undef HAVE_EncryptAes128Ctr */
+#define HAVE_EncryptAes128Ctr 1
 /* #undef HAVE_EncryptAes128Gcm */
 #define HAVE_des 1
-
-/*
-  Stuff that always need to be defined (compile breaks without it)
-*/
-#define HAVE_SPATIAL 1
-#define HAVE_RTREE_KEYS 1
-#define HAVE_QUERY_CACHE 1
-#define BIG_TABLES 1
+#define HAVE_hkdf 1
 
 /*
   Important storage engines (those that really need define 
@@ -524,18 +517,18 @@ this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
 
 /* #undef SO_EXT */
 
-#define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 11
-#define MYSQL_VERSION_PATCH 16
+#define MYSQL_VERSION_MAJOR 11
+#define MYSQL_VERSION_MINOR 8
+#define MYSQL_VERSION_PATCH 3
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.11.16"
+#define PACKAGE_STRING "MySQL Server 11.8.3"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.11.16"
-#define VERSION "10.11.16"
+#define PACKAGE_VERSION "11.8.3"
+#define VERSION "11.8.3"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
